==> zio-aws-eks_2.12-5.17.155.2-sources.jar: zio/aws/eks/model/DisassociateIdentityProviderConfigResponse.scala <==
package zio.aws.eks.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DisassociateIdentityProviderConfigResponse(
    update: Option[zio.aws.eks.model.Update] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.eks.model.DisassociateIdentityProviderConfigResponse = {
    import DisassociateIdentityProviderConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.eks.model.DisassociateIdentityProviderConfigResponse
      .builder()
      .optionallyWith(update.map(value => value.buildAwsValue()))(_.update)
      .build()
  }
  def asReadOnly
      : zio.aws.eks.model.DisassociateIdentityProviderConfigResponse.ReadOnly =
    zio.aws.eks.model.DisassociateIdentityProviderConfigResponse
      .wrap(buildAwsValue())
}
object DisassociateIdentityProviderConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.eks.model.DisassociateIdentityProviderConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.eks.model.DisassociateIdentityProviderConfigResponse =
      zio.aws.eks.model.DisassociateIdentityProviderConfigResponse(
        update.map(value => value.asEditable)
      )
    def update: Option[zio.aws.eks.model.Update.ReadOnly]
    def getUpdate: ZIO[Any, AwsError, zio.aws.eks.model.Update.ReadOnly] =
      AwsError.unwrapOptionField("update", update)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.eks.model.DisassociateIdentityProviderConfigResponse
  ) extends zio.aws.eks.model.DisassociateIdentityProviderConfigResponse.ReadOnly {
    override val update: Option[zio.aws.eks.model.Update.ReadOnly] = scala
      .Option(impl.update())
      .map(value => zio.aws.eks.model.Update.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.eks.model.DisassociateIdentityProviderConfigResponse
  ): zio.aws.eks.model.DisassociateIdentityProviderConfigResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-eks_2.13-5.17.162.2-sources.jar: zio/aws/eks/model/DisassociateIdentityProviderConfigResponse.scala <==
package zio.aws.eks.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DisassociateIdentityProviderConfigResponse(
    update: Optional[zio.aws.eks.model.Update] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.eks.model.DisassociateIdentityProviderConfigResponse = {
    import DisassociateIdentityProviderConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.eks.model.DisassociateIdentityProviderConfigResponse
      .builder()
      .optionallyWith(update.map(value => value.buildAwsValue()))(_.update)
      .build()
  }
  def asReadOnly
      : zio.aws.eks.model.DisassociateIdentityProviderConfigResponse.ReadOnly =
    zio.aws.eks.model.DisassociateIdentityProviderConfigResponse
      .wrap(buildAwsValue())
}
object DisassociateIdentityProviderConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.eks.model.DisassociateIdentityProviderConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.eks.model.DisassociateIdentityProviderConfigResponse =
      zio.aws.eks.model.DisassociateIdentityProviderConfigResponse(
        update.map(value => value.asEditable)
      )
    def update: Optional[zio.aws.eks.model.Update.ReadOnly]
    def getUpdate: ZIO[Any, AwsError, zio.aws.eks.model.Update.ReadOnly] =
      AwsError.unwrapOptionField("update", update)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.eks.model.DisassociateIdentityProviderConfigResponse
  ) extends zio.aws.eks.model.DisassociateIdentityProviderConfigResponse.ReadOnly {
    override val update: Optional[zio.aws.eks.model.Update.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.update())
        .map(value => zio.aws.eks.model.Update.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.eks.model.DisassociateIdentityProviderConfigResponse
  ): zio.aws.eks.model.DisassociateIdentityProviderConfigResponse.ReadOnly =
    new Wrapper(impl)
}
